@@ -37,3 +37,7 @@ class Configuration :
         return yaml_origin
 
         
+    def extend(self,other):
+
+        for k,v in other._origin_prefixes.items():
+            self._origin_prefixes[k]=v
