@@ -30,24 +30,14 @@ class Project(object):
                   parent_projects,
                   repositories,
                   users=None):
-        """ 
-        Parameters
-        ----------
-        name: str
-            name of this project
-        projects: list of Projects 
-            iterable of instance of projects that will be included in this project
-        repositories : list of str
-            list of names of repos contained by this project
-        users: list of str, optional
-            list of user names of this project
-        """
+
         self.name = name
         self.parent_projects = parent_projects
         self.repositories = repositories
         self.users = None
 
     def get_users(self):
+
         return copy.deepcopy(self._users)
 
     
