@@ -744,10 +744,14 @@ class Projects :
 
         if hosts_not_established:
             if raise_exception:
-                raise Exception("authenticity of servers "+", ".join(hosts_not_established)+" could not be established")
+                raise Exception("authenticity of servers "+", ".join(hosts_not_established)+
+                                " could not be established")
             if console:
-                print("\n\t",coloring.red("[ERROR]"),"authenticity of at least one server could not be established.")
-                print("\t",coloring.dim("possible fix: clone manually a repo from this server to establish authenticity via prompt\n"))
+                print("\n\t",
+                      coloring.red("[ERROR]"),
+                      "authenticity of at least one server could not be established.")
+                print("\t",
+                      coloring.dim("possible fix: clone manually a repo from this server to establish authenticity via prompt\n"))
         
         # informing user with start to clone
         if console:
@@ -798,9 +802,11 @@ class Projects :
 
                 if key=="branch" :
                     fn = treep_git.checkout_branch
-                else:
+                elif key=="commit" :
                     fn = treep_git.checkout_commit
-                
+                elif key=="tag" :
+                    fn = treep_git.checkout_tag
+                    
                 try:
                     fn(config["path"],
                        config[key])
@@ -861,7 +867,16 @@ class Projects :
                             # shared error and output also
                             # updated when exception throw in checkout
                             pass
-                
+
+                    # checking out tag
+                    if config["tag"] and config["tag"]!=status.commit_sha1:
+                        try:
+                            _checkout(config,"tag",output)
+                        except :
+                            # shared error and output also
+                            # updated when exception throw in checkout
+                            pass
+                        
                 except Exception as e :
                     if nb_attempts<20:
                         time.sleep(0.01)
