@@ -18,6 +18,11 @@
 
 
 from . import coloring
+import sys
+
+
+_UPWARD = u'\u25B2'
+_DOWNWARD = u'\u25BC'
 
 
 class Status(object):
@@ -107,7 +112,7 @@ class Status(object):
 
         # formatted status message, if any
         if self.status_message:
-            lines = self.status_message[2:-1].split("\\n")
+            lines = self.status_message[2:-1].split("\n")
             for line in lines:
                 if line:
                     s.append("\n\t\t\t\t"+coloring.cyan(line))
@@ -116,7 +121,59 @@ class Status(object):
         print (" ".join([str(a) for a in s]))
         
 
+    def short_print(self,workspace_path):
 
+        global _UPWARD
+        global _DOWNWARD
+
+        s = ["\t\t"]
+
+        # repository name
+
+        modified = False
+        if self.ahead_origin :
+            modified = True
+        if self.behind_origin:
+            modified = True
+        if self.nb_modified_files is not None and self.nb_modified_files>0 :
+            modified = True
+            
+        if not modified:
+            s.append( coloring.b_green(self.repo_name) )
+        else :
+            s.append( coloring.b_red(self.repo_name) )
+
+        # current branch
+
+        if self.branch == "master":
+            branch = coloring.b_cyan("master")
+        else :
+            branch = coloring.b_blue(self.branch)
+        s.append( branch )
+
+        # info about status: ahead, behind, number of modified files
+
+        # python3 
+        if (sys.version_info > (3, 0)):
+            if self.ahead_origin :
+                s.append(coloring.b_red(_UPWARD))
+            if self.behind_origin:
+                s.append(coloring.b_orange(_DOWNWARD))
+        # python2
+        else : 
+            if self.ahead_origin :
+                s.append(coloring.b_red(_UPWARD.encode('utf-8')))
+            if self.behind_origin:
+                s.append(coloring.b_red(_DOWNWARD.encode('utf-8')))
+                
+        if self.nb_modified_files is not None and self.nb_modified_files>0 :
+            if self.nb_modified_files>1: s_='s'
+            else : s_=''
+            s.append(coloring.b_red("("+str(self.nb_modified_files)+")"))
+
+        print ("\t".join([str(a) for a in s]))
+
+        
 def pretty_print(statuses,workspace_path):
 
     print("\n\t"+coloring.b_green("STATUS"))
@@ -129,5 +186,22 @@ def pretty_print(statuses,workspace_path):
         status.pretty_print(workspace_path)
 
     print("")
+
+
+        
+
+
+def short_print(statuses,workspace_path):
+
+    print("\n\t"+coloring.b_green("STATUS"))
     
+    statuses_ = sorted(statuses,key = lambda status: status.repo_name)
+
+    print ("")
+    
+    for status in statuses_:
+        status.short_print(workspace_path)
+
+    print("")
+
     
